@@ -3,6 +3,7 @@ import logging
 import os
 import tempfile
 from datetime import datetime
+from typing import Optional
 
 import click
 from nowcasting_datamodel.connection import DatabaseConnection
@@ -31,7 +32,7 @@ logger = logging.getLogger(__name__)
 logger.setLevel(
     level=getattr(logging, os.getenv("LOGLEVEL", "DEBUG")),
 )
-logging.getLogger('nowcasting_forecast').setLevel(
+logging.getLogger("nowcasting_forecast").setLevel(
     level=getattr(logging, os.getenv("LOGLEVEL", "DEBUG")),
 )
 # TODO make logs show up in AWS
@@ -59,7 +60,19 @@ logging.getLogger('nowcasting_forecast').setLevel(
     help="Select which model to use",
     type=click.STRING,
 )
-def run(db_url: str, fake: bool = False, model_name: str = "nwp_simple"):
+@click.option(
+    "--batch-save-dir",
+    default=None,
+    envvar="BATCH_SAVE_DIR",
+    help="Optional directory to save first bacth to",
+    type=click.STRING,
+)
+def run(
+    db_url: str,
+    fake: bool = False,
+    model_name: str = "nwp_simple",
+    batch_save_dir: Optional[str] = None,
+):
     """
     Run main app.
 
@@ -86,7 +99,12 @@ def run(db_url: str, fake: bool = False, model_name: str = "nwp_simple"):
 
             with tempfile.TemporaryDirectory() as temporary_dir:
                 # make batches
-                make_batches(temporary_dir=temporary_dir, config_filename=config_filename)
+                save_dir = batch_save_dir + "batch/" if batch_save_dir is not None else None
+                make_batches(
+                    temporary_dir=temporary_dir,
+                    config_filename=config_filename,
+                    batch_save_dir=save_dir,
+                )
 
                 # make forecasts
                 if model_name == "nwp_simple":
@@ -106,17 +124,20 @@ def run(db_url: str, fake: bool = False, model_name: str = "nwp_simple"):
                         ml_model=Model,
                     )
                 elif model_name == "cnn":
-                    dataloader = get_cnn_data_loader(src_path=f'{temporary_dir}/live',
-                                                     tmp_path=f'{temporary_dir}/live')
+                    dataloader = get_cnn_data_loader(
+                        src_path=f"{temporary_dir}/live",
+                        tmp_path=f"{temporary_dir}/live",
+                        batch_save_dir=batch_save_dir,
+                    )
                     forecasts = general_forecast_run_all_batches(
                         session=session,
                         batches_dir=temporary_dir,
                         callable_function_for_on_batch=cnn_run_one_batch,
-                        model_name="nwp_simple_trained",
+                        model_name="cnn",
                         ml_model=CNN_Model,
                         dataloader=dataloader,
                         use_hf=True,
-                        configuration_file="nowcasting_forecast/config/mvp_v2.yaml"
+                        configuration_file="nowcasting_forecast/config/mvp_v2.yaml",
                     )
                 else:
                     raise NotImplementedError(f"model name {model_name} has not be implemented. ")
